# FORCE_EFI_BOOT

echo -off
# +
# + ============================================================== +
#  Copyright (c) 2022, Intel Corporation.

#  This source code and any documentation accompanying it ("Material") is furnished
#  under license and may only be used or copied in accordance with the terms of that
#  license.  No license, express or implied, by estoppel or otherwise, to any
#  intellectual property rights is granted to you by disclosure or delivery of these
#  Materials.  The Materials are subject to change without notice and should not be
#  construed as a commitment by Intel Corporation to market, license, sell or support
#  any product or technology.  Unless otherwise provided for in the license under which
#  this Material is provided, the Material is provided AS IS, with no warranties of
#  any kind, express or implied, including without limitation the implied warranties
#  of fitness, merchantability, or non-infringement.  Except as expressly permitted by
#  the license for the Material, neither Intel Corporation nor its suppliers assumes
#  any responsibility for any errors or inaccuracies that may appear herein.  Except
#  as expressly permitted by the license for the Material, no part of the Material
#  may be reproduced, stored in a retrieval system, transmitted in any form, or
#  distributed by any means without the express written consent of Intel Corporation.

#  Module Name:  Startup.nsh

#  Abstract:  UEFI Script file for invoking system software updates for 
#  Intel(R) Server Board M50CYP Family.

# + ============================================================== +
#    Program all firmware from capsule file 
# + ============================================================== +

@echo -off
mode 80 25
:foundimage section is simply to locate the correct drive

if exist .\ipmi.efi then
    goto FOUNDIMAGE
endif
if exist fs0:\ipmi.efi then
    fs0:
    echo Found Update Packages on fs0:
    goto FOUNDIMAGE
endif
if exist fs1:\ipmi.efi then
    fs1:
    echo Found Update Packages on fs1:
    goto FOUNDIMAGE
endif
if exist fs2:\ipmi.efi then
    fs2:
    echo Found Update Packages on fs2:
    goto FOUNDIMAGE
endif
    echo "Unable to find Update Packages".  
    echo "Please mount the drive with the update package".
    echo ""
    goto END
:FOUNDIMAGE



echo "==============================================================================="
echo " "
echo "This utility will update CPLD,Pmem,BMC,FRUSDR,BIOS Firmware"
echo " "
echo "      - Intel(R) Server Board M50CYP Family"
echo " "
echo "If you have not read the Readme and Update Instructions,"
echo "it is highly advisable you do that before running this update."
echo " "
echo "The Whole Firmware Update may take 18+ Minutes, During the process:"
echo "1. Don't REMOVE Power Cable while updating firmware!!!"
echo "2. Don't PRESS Power Button while updating firmware!!!"
echo "3. Don't REMOVE the USB flash drive while updating firmware!!!"
echo "   OR ELSE, you may render your system Inoperable!!!!"
echo "4. During the update process, SUT will be reset after BIOS update!!!"
echo "5. Please make sure no *pass.tmp on USB drive before starting this update"
echo " "
echo "For firmware updates and troubleshooting tips, visit https://www.intel.com/support/serverbios"
echo " "
echo "==============================================================================="
stall 3000000

#only print current version one time
if exist BMC_pass.tmp then
    echo " "
else
# If no need version check to skip same update, comment following line with '#'.
    FwVerCheck.nsh 
endif    


echo " "
echo "Update Sequence:"
echo "==============================================================================="
echo "1. Update CPLD     - No reset after complete update"
echo "2. Update Pmem FW  - If populated, No reset after complete update"
echo "3. Update BMC      - No reset after complete update"
echo "4. Update FRUSDR   - No reset after complete update"
echo "5. Update BIOS     - Reset SUT immediately after BIOS complete update"
echo "6. Wait for 12+ minutes, SUT should boot up successfully" 
echo " "
echo "Recovery firmware will be updated automatically once factory version firmware is detected"
echo " "
echo "For detail, please refer Readme and Update Instructions file."
echo " "
echo "CPLD -> Pmem -> BMC -> FRUSDR -> BIOS -> Reset"
echo "==============================================================================="

stall 3000000


:A
 
if exist CPLD_pass.tmp then 
    if exist Pmem_pass.tmp then
        if exist BMC_pass.tmp then 
            if exist FRUSDR_pass.tmp then
                if exist BIOS_pass.tmp then 
                    goto Final
                else
                    if exist  UpdBIOSRecovery.tmp then 
                        goto BIOSRecovery   
                    else  
                        goto BIOS
                    endif                             
                endif 
            else
                goto FRUSDR
            endif 
        else
            if exist UpdBMCRecovery.tmp then
                goto BMCRecovery
            else
                goto BMC
            endif
        endif
    else
        goto Pmem
    endif
else
    if exist UpdCPLDRecovery.tmp then
        goto CPLDRecovery
    else
        goto CPLD
    endif
endif


:BMC
echo " "
echo "==============================================================================="
echo "Start BMC Active Firmware Update......"
echo "DO NOT remove USB flash drive!!!"
UpdBMC_CYP.nsh 
echo "Updating BMC Firmware ..............." > BMC_pass.tmp
echo "Need reset SUT ......................" > NeedReset.tmp
goto A


:BMCRecovery
echo " "
echo "==============================================================================="
echo "Start BMC Active+Recovery Firmware Update......"
echo "DO NOT remove USB flash drive"
UpdBMCRecovery_CYP.nsh
echo "Updating BMC Firmware ..............." > BMC_pass.tmp
echo "Need reset SUT ......................" > NeedReset.tmp
goto A


:BIOS
echo " "
echo "==============================================================================="
echo "Start to update BIOS firmware ......"
echo "DO NOT remove USB flash drive!!!"

#note:removing all pass.tmp files because bios will immreset

echo "Start to update BIOS firmware ...... " > BIOS_pass.tmp 
del *.tmp > nul
    UpdBIOS_CYP.nsh 
goto A


:BIOSRecovery
echo " "
echo "Start to update recovery BIOS ......" > BIOS_pass.tmp
del *.tmp > nul
#update bios active and recovery then reboot SUT automatically 

    UpdBIOSRecovery_CYP.nsh

goto A

:CPLD
echo " "
echo "==============================================================================="
echo "Start to update CPLD firmware ......"
echo "DO NOT remove USB flash drive!!!"
UpdCPLD_CYP.nsh
echo "Start to update CPLD ......" > CPLD_pass.tmp
echo "Need reset SUT ............" > NeedReset.tmp
goto A

:CPLDRecovery
echo " "
echo "==============================================================================="
echo "Start to update Recovery CPLD ......"
echo "DO NOT remove USB flash drive!!!"
UpdCPLDRecovery_CYP.nsh
echo "Start to update Recovery CPLD ......" > CPLD_pass.tmp
echo "Need reset SUT ....................." > NeedReset.tmp
goto A


:FRUSDR
echo " "
echo "==============================================================================="
echo "Start to update FRUSDR......"
echo "DO NOT remove USB flash drive"

echo " "
 
UpdM50FruSdr_CYP.nsh

echo " "
echo "System FRU & SDR data have been updated successfully" > FRUSDR_pass.tmp
goto A

:Pmem
if exist ipmctl.efi then                      
    ipmctl.efi show -dimm > noPmem.tmp  # check Pmem  installed or not 
    comp noPmem.log noPmem.tmp > comp.tmp
    if %lasterror% == 0 then
        echo " "
        echo "No Pmem DIMM Populated, Skip Pmem FW Update" > Pmem_pass.tmp 
    else
        echo " "
        echo "Found Pmem DIMM(s) Populated"
        echo "Updating Pmem firmware"
        echo " "
        echo " "
        echo "==============================================================================="
        echo "DO NOT remove USB flash drive!!!"
        echo " "

        UpdatePmemFW.nsh

        echo " "
        echo " "
        echo "Updating Pmem FW..........Done" > Pmem_pass.tmp 
        echo "Updating Pmem need reset........" > NeedReset.tmp

    endif
endif 
goto A

:Final
if exist NeedReset.tmp then
    del *.tmp > nul 
    Reset -C 
endif 

echo "Removing tmp files..."
del *.tmp > nul


echo "==============================================================================="
echo "All Firmware Updates have been completed now"
echo " "
echo "Now USB Flash Drive can be removed then power cycle the system."
echo "During POST, Access BIOS Setup utility with <F2> to confirm all FW update properly."

:END
 